@@ -19,7 +19,7 @@ class DataPlot(object):
     
     """
     def __init__(self, elem=None, spec=None, all_data=[], atom=None, n_tem_points=10000, 
-                 ref_tem=None, OmegaInterp='Cheb'):
+                 ref_tem=None, OmegaInterp='Cheb',NLevels=None):
         """
     Parameters:
         - elem         atomic elem 
@@ -83,18 +83,19 @@ class DataPlot(object):
             coll_data_temp.append(item)
         for data in coll_data_temp:
             pn.atomicData.setDataFile(data['file_'])
-            atom = pn.Atom(self.elem, self.spec, OmegaInterp=OmegaInterp)
+            atom = pn.Atom(self.elem, self.spec, OmegaInterp=OmegaInterp, NLevels=NLevels)
+            """
             try:
-                if ('COEFF' in atom.CollData.comments.keys()) or ('O_UNIT' in atom.CollData.comments.keys()):
+                if 'O_UNIT' in atom.CollData.comments.keys():
                     self.coll_data.remove(data)
             except:
                 pass
-
+            """
         # For each data set, an atom is built. 
         del(atom)
         for data in self.atom_data + self.coll_data:
             pn.atomicData.setDataFile(data['file_'])
-            atom = pn.Atom(self.elem, self.spec, OmegaInterp=OmegaInterp)
+            atom = pn.Atom(self.elem, self.spec, OmegaInterp=OmegaInterp, NLevels=NLevels)
             data['atom'] = atom
         for data in old_data:
             if data is not None:
@@ -235,12 +236,11 @@ class DataPlot(object):
                     ax.text(0.95, 0.95, lbl, fontsize=10, color="#660066", transform=ax.transAxes, ha="right", va="top")                                    
                 except:
                     pn.log_.warn('Problem with plotting a subplot {} {}'.format(i,j), calling=self.calling)
-        
+                if (j==atom_n_max) & (i==1):  
+                    plt.xlabel('Reference #', fontsize=8)
+                    plt.ylabel('Log(A$_{ji}$)', fontsize=8)
         plt.subplots_adjust(left=0.15, right=0.95, top=0.95, bottom=0.12)
         plt.gca().get_yaxis().get_major_formatter().set_useOffset(False)
-        ax=plt.subplot(atom_n_max - 1, atom_n_max - 1, (atom_n_max-1)*(atom_n_max-2) + 1)
-        plt.xlabel('Reference #', fontsize=8)
-        plt.ylabel('Log(A$_{ji}$)', fontsize=8)
         ax.set_xticks(x)
         
         fig.text(.5, .05, "i (lower level)", fontsize=12, ha='center', color="#660066", va='top')
@@ -259,7 +259,7 @@ class DataPlot(object):
         plt.show()      
         
 
-    def plotRelA(self, ref_data=None, save=False, figsize=(18, 12), fignum=None, NLevels=None):
+    def plotRelA(self, ref_data=None, save=False, figsize=None, fignum=None, NLevels=None, fig=None):
         """
         Plot the relative difference of the A of each data set with respect to the reference one
 
@@ -276,8 +276,10 @@ class DataPlot(object):
             atom_n_max = NLevels
         if not pn.config.INSTALLED['plt']:
             pn.log_.error('Matplotlib not installed!', calling=self.calling)
-        plt.figure(fignum, figsize=figsize)
-        plt.clf()
+        # Commented out because it produced an extra, empty frame - VL 30 Jul 2015
+        #if fig is None:
+        #    fig = plt.figure(fignum, figsize=figsize)
+        #plt.clf()
         ticks = range(atom_n_max + 1)[1:]
 
         # The As of the reference data set are stored
@@ -304,9 +306,12 @@ class DataPlot(object):
                     nonzero_A_ratio_indexes = np.nonzero(A_ratio)
                     rel_A = np.log10(A_ratio[nonzero_A_ratio_indexes])
                     # Plotting starts
-                    fig = plt.figure()
+                    #fig = plt.figure()
+                    if fig is None:
+                        fig = plt.figure(fignum, figsize=figsize)
+                    plt.clf()
                     ax = plt.subplot(111, axisbg='#FFFFE0')
-                    fig.subplots_adjust(top=0.85)
+                    fig.subplots_adjust(top=0.9)
                     # Physical levels = array levels + 1
                     x = np.asarray(lo_indexes) + 1
                     y = np.asarray(up_indexes) + 1
@@ -344,7 +349,7 @@ class DataPlot(object):
                     plt.scatter(x[index_grt], y[index_grt], marker='o', s=size[index_grt], c=np.asarray(color_grt), alpha=1.0)
                     plt.scatter(x[index_sml], y[index_sml], marker='o', s=size[index_sml], c=np.asarray(color_sml), alpha=1.0)
                     # X-axis label 
-                    ax.text(.5, 1.03, '$i$ (lower level)', transform=ax.transAxes, ha='center', va='bottom')
+                    ax.text(.5, 1.05, '$i$ (lower level)', transform=ax.transAxes, ha='center', va='bottom')
                     #plt.xlabel('$i$ (lower level)')
                     # Y-axis label
                     plt.ylabel('$j$ (upper level)')
@@ -352,7 +357,7 @@ class DataPlot(object):
                     plt.legend(loc='upper right', markerscale=1000., scatterpoints=1, borderpad=1,
                                labelspacing=1, prop=dict(size=12), title=u'Log (%s / %s)' % (data['ID'], ref_data))
                     # Plot title
-                    ax.text(.5, 1.10, "Relative difference between $A$s data for [%s %s]" 
+                    ax.text(.5, -.10, "Relative difference between $A$s data for [%s %s]" 
                                 % (self.elem, int_to_roman(int(self.spec))),
                                 transform=ax.transAxes, ha='center', va='bottom', color='#191970', size=12)
                 except:
@@ -364,7 +369,7 @@ class DataPlot(object):
                 plt.show()      
 
 
-    def plotOmega(self, save=False, figsize=(18, 12), fignum=None, scan_orders=None, NLevels=None,
+    def plotOmega(self, save=False, figsize=(18, 12), fignum=1, scan_orders=None, NLevels=None,
                   fig=None):
         """
         Plot the tabulated collision strengths of each data set and the fit that is performed by PyNeb
@@ -403,6 +408,10 @@ class DataPlot(object):
             tem_funct = np.linspace(tem_min, tem_max, self.n_tem_points)
             x_dots = np.log10(tem_points)
             x_lines = np.log10(tem_funct)
+            if 'COEFF' in data['atom'].CollData.comments.keys():
+                coeff = float(data['atom'].CollData.comments['COEFF'])
+            else:
+                coeff = 1.0
             # Loops over all levels
             for i in range(1, coll_n_max+1):
                 for j in range(i + 1, coll_n_max+1):                
@@ -413,8 +422,15 @@ class DataPlot(object):
                                          (coll_n_max-1) * (j - 2) + i,
                                          axisbg='#FFFFE0')
                         if (i <= data['atom'].collNLevels) and (j <= data['atom'].collNLevels):
+                            y_dots = data['atom'].getOmega(tem_points, j, i)
                             try:
-                                y_dots = data['atom'].getOmegaArray(j, i)
+                                if 'O_UNIT' not in data['atom'].CollData.comments:
+                                    y_dots = coeff * data['atom'].getOmegaArray(j, i)
+                                    if y_dots.sum() > 0.0:
+                                        ax.plot(x_dots, y_dots, color=data['color'],
+                                                marker='*', linestyle='None', label='_nolegend_', markersize=10)
+                                    
+                                y_dots = data['atom'].getOmega(tem_points, j, i)
                                 if y_dots.sum() > 0.0:
                                     ax.plot(x_dots, y_dots, color=data['color'],
                                             marker='o', linestyle='None', label='_nolegend_')
@@ -448,8 +464,10 @@ class DataPlot(object):
         fig.text(.05, .5, "$\Omega$", va='center', fontsize=20, rotation=90)
         fig.text(.5, .95, "[%s %s] collision strengths" % (self.elem, int_to_roman(int(self.spec))), 
                  color="#191970", fontsize=16, ha='center')
+#        plt.legend(legend_lines, legend_text, loc='upper right', borderpad=1, 
+#                   labelspacing=1, bbox_to_anchor=(1, 1 * coll_n_max))
         plt.legend(legend_lines, legend_text, loc='upper right', borderpad=1, 
-                   labelspacing=1, bbox_to_anchor=(1, 1 * coll_n_max))
+                   labelspacing=1, bbox_to_anchor=(1, coll_n_max - 1))
         #plt.tight_layout()
         if save:
             plt.savefig(self.atom_rom + "_CS.pdf")
